BoundingBox2D

Struct BoundingBox2D 

pub struct BoundingBox2D {
    pub min: Vector2,
    pub max: Vector2,
}
2D bounding box

Fields

min: Vector2

Minimum point (lower-left corner)

max: Vector2

Maximum point (upper-right corner)

Implementations

Source

impl BoundingBox2D

pub fn new(min: Vector2, max: Vector2) -> Self

Create a new bounding box from min and max points

pub fn from_point(point: Vector2) -> Self

Create a bounding box from a single point

pub fn from_points(points: &[Vector2]) -> Option<Self>

Create a bounding box that contains all given points

pub fn width(&self) -> f64

Get the width of the bounding box

pub fn height(&self) -> f64

Get the height of the bounding box

pub fn center(&self) -> Vector2

Get the center point of the bounding box

pub fn contains(&self, point: Vector2) -> bool

Check if this bounding box contains a point

pub fn expand_to_include(&mut self, point: Vector2)

Expand the bounding box to include another point

pub fn merge(&self, other: &BoundingBox2D) -> BoundingBox2D

Merge with another bounding box