pub struct BoundingBox2D {
pub min: Vector2,
pub max: Vector2,
}Expand description
2D bounding box
Fields
min: Vector2Minimum point (lower-left corner)
max: Vector2Maximum point (upper-right corner)
Implementations
Sourceimpl BoundingBox2D
impl BoundingBox2D
Sourcepub fn new(min: Vector2, max: Vector2) -> Self
pub fn new(min: Vector2, max: Vector2) -> Self
Create a new bounding box from min and max points
Sourcepub fn from_point(point: Vector2) -> Self
pub fn from_point(point: Vector2) -> Self
Create a bounding box from a single point
Sourcepub fn from_points(points: &[Vector2]) -> Option<Self>
pub fn from_points(points: &[Vector2]) -> Option<Self>
Create a bounding box that contains all given points
Sourcepub fn expand_to_include(&mut self, point: Vector2)
pub fn expand_to_include(&mut self, point: Vector2)
Expand the bounding box to include another point
Sourcepub fn merge(&self, other: &BoundingBox2D) -> BoundingBox2D
pub fn merge(&self, other: &BoundingBox2D) -> BoundingBox2D
Merge with another bounding box